pub enum PinLockType {
BeforeFirstUnlock,
AfterFirstUnlock,
}Expand description
Pin unlock can be configured to use one of two modes. Before-first-unlock and after-first-unlock. In AFU mode, the PIN is available only after unlocking once with the master password or another unlock method. In BFU mode, PIN unlock is available right after app start. For this, the PIN-encrypted vault key is stored on disk.
Variants
BeforeFirstUnlock
Pin unlock is available after app start
AfterFirstUnlock
Pin unlock is available after unlocking with another method at least once during the app session