pub struct LocalUserDataKeyState {
wrapped_key: EncString,
}Expand description
Represents the local user data key, wrapped by user key. This key is used to encrypt local user data (e.g., password generator history).
Fields
wrapped_key: EncStringTrait Implementations
Sourceimpl Clone for LocalUserDataKeyState
impl Clone for LocalUserDataKeyState
Sourcefn clone(&self) -> LocalUserDataKeyState
fn clone(&self) -> LocalUserDataKeyState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for LocalUserDataKeyState
impl<UT> ConvertError<UT> for LocalUserDataKeyState
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for LocalUserDataKeyState
impl Debug for LocalUserDataKeyState
Sourceimpl<'de> Deserialize<'de> for LocalUserDataKeyState
impl<'de> Deserialize<'de> for LocalUserDataKeyState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for LocalUserDataKeyState
impl<UT> FfiConverter<UT> for LocalUserDataKeyState
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<LocalUserDataKeyState> for JsValuewhere
LocalUserDataKeyState: Serialize,
impl From<LocalUserDataKeyState> for JsValuewhere
LocalUserDataKeyState: Serialize,
Sourcefn from(value: LocalUserDataKeyState) -> Self
fn from(value: LocalUserDataKeyState) -> Self
Converts to this type from the input type.
Sourceimpl From<WrappedLocalUserDataKey> for LocalUserDataKeyState
impl From<WrappedLocalUserDataKey> for LocalUserDataKeyState
Sourcefn from(wrapped_key: WrappedLocalUserDataKey) -> Self
fn from(wrapped_key: WrappedLocalUserDataKey) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
impl FromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
impl IntoWasmAbi for &LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
Sourceimpl IntoWasmAbi for LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
impl IntoWasmAbi for LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
Sourceimpl<UT> Lift<UT> for LocalUserDataKeyState
impl<UT> Lift<UT> for LocalUserDataKeyState
Sourceimpl<UT> LiftRef<UT> for LocalUserDataKeyState
impl<UT> LiftRef<UT> for LocalUserDataKeyState
Sourceimpl<UT> LiftReturn<UT> for LocalUserDataKeyState
impl<UT> LiftReturn<UT> for LocalUserDataKeyState
Sourcetype ReturnType = <LocalUserDataKeyState as Lift<UT>>::FfiType
type ReturnType = <LocalUserDataKeyState as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for LocalUserDataKeyState
impl<UT> Lower<UT> for LocalUserDataKeyState
Sourceimpl<UT> LowerError<UT> for LocalUserDataKeyState
impl<UT> LowerError<UT> for LocalUserDataKeyState
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for LocalUserDataKeyState
impl<UT> LowerReturn<UT> for LocalUserDataKeyState
Sourcetype ReturnType = <LocalUserDataKeyState as Lower<UT>>::FfiType
type ReturnType = <LocalUserDataKeyState as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
impl OptionIntoWasmAbi for LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
Sourceimpl RefFromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<LocalUserDataKeyState>
type Anchor = SelfOwner<LocalUserDataKeyState>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl RepositoryItem for LocalUserDataKeyState
impl RepositoryItem for LocalUserDataKeyState
Sourcefn data() -> RepositoryItemData
fn data() -> RepositoryItemData
Returns metadata about the repository item type.
Sourceimpl Serialize for LocalUserDataKeyState
impl Serialize for LocalUserDataKeyState
Sourceimpl Tsify for LocalUserDataKeyState
impl Tsify for LocalUserDataKeyState
const DECL: &'static str = "/**\n * Represents the local user data key, wrapped by user key.\n * This key is used to encrypt local user data (e.g., password generator history).\n */\nexport interface LocalUserDataKeyState {\n wrapped_key: EncString;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for LocalUserDataKeyState
impl<UT> TypeId<UT> for LocalUserDataKeyState
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for LocalUserDataKeyStatewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
impl VectorIntoWasmAbi for LocalUserDataKeyStatewhere
LocalUserDataKeyState: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for LocalUserDataKeyState
impl WasmDescribe for LocalUserDataKeyState
impl Internal for LocalUserDataKeyState