#[repr(transparent)]pub struct UserKeyState {
decrypted_user_key: B64,
}Expand description
Represents the decrypted symmetric user-key of a user. This is held in ephemeral state of the client.
Fields
decrypted_user_key: B64Trait Implementations
Sourceimpl Clone for UserKeyState
impl Clone for UserKeyState
Sourcefn clone(&self) -> UserKeyState
fn clone(&self) -> UserKeyState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for UserKeyState
impl<UT> ConvertError<UT> for UserKeyState
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for UserKeyState
impl Debug for UserKeyState
Sourceimpl<'de> Deserialize<'de> for UserKeyState
impl<'de> Deserialize<'de> for UserKeyState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for UserKeyState
impl<UT> FfiConverter<UT> for UserKeyState
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<UserKeyState> for JsValuewhere
UserKeyState: Serialize,
impl From<UserKeyState> for JsValuewhere
UserKeyState: Serialize,
Sourcefn from(value: UserKeyState) -> Self
fn from(value: UserKeyState) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
impl FromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &UserKeyStatewhere
UserKeyState: Serialize,
impl IntoWasmAbi for &UserKeyStatewhere
UserKeyState: Serialize,
Sourceimpl IntoWasmAbi for UserKeyStatewhere
UserKeyState: Serialize,
impl IntoWasmAbi for UserKeyStatewhere
UserKeyState: Serialize,
Sourceimpl<UT> Lift<UT> for UserKeyState
impl<UT> Lift<UT> for UserKeyState
Sourceimpl<UT> LiftRef<UT> for UserKeyState
impl<UT> LiftRef<UT> for UserKeyState
type LiftType = UserKeyState
Sourceimpl<UT> LiftReturn<UT> for UserKeyState
impl<UT> LiftReturn<UT> for UserKeyState
Sourcetype ReturnType = <UserKeyState as Lift<UT>>::FfiType
type ReturnType = <UserKeyState as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for UserKeyState
impl<UT> Lower<UT> for UserKeyState
Sourceimpl<UT> LowerError<UT> for UserKeyState
impl<UT> LowerError<UT> for UserKeyState
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for UserKeyState
impl<UT> LowerReturn<UT> for UserKeyState
Sourcetype ReturnType = <UserKeyState as Lower<UT>>::FfiType
type ReturnType = <UserKeyState as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for UserKeyStatewhere
UserKeyState: Serialize,
impl OptionIntoWasmAbi for UserKeyStatewhere
UserKeyState: Serialize,
Sourceimpl RefFromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<UserKeyState>
type Anchor = SelfOwner<UserKeyState>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl RepositoryItem for UserKeyState
impl RepositoryItem for UserKeyState
Sourcefn data() -> RepositoryItemData
fn data() -> RepositoryItemData
Returns metadata about the repository item type.
Sourceimpl Serialize for UserKeyState
impl Serialize for UserKeyState
Sourceimpl Tsify for UserKeyState
impl Tsify for UserKeyState
const DECL: &'static str = "/**\n * Represents the decrypted symmetric user-key of a user. This is held in ephemeral state of the\n * client.\n */\nexport interface UserKeyState {\n decrypted_user_key: B64;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for UserKeyState
impl<UT> TypeId<UT> for UserKeyState
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for UserKeyStatewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for UserKeyStatewhere
UserKeyState: Serialize,
impl VectorIntoWasmAbi for UserKeyStatewhere
UserKeyState: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for UserKeyState
impl WasmDescribe for UserKeyState
Sourceimpl WasmDescribeVector for UserKeyState
impl WasmDescribeVector for UserKeyState
impl Internal for UserKeyState