pub struct V2EncryptedMigrationsGracePeriodStart(pub DateTime<Utc>);Expand description
Records when the user first became eligible for v2 encrypted migrations.
Tuple Fields
0: DateTime<Utc>Trait Implementations
Sourceimpl Clone for V2EncryptedMigrationsGracePeriodStart
impl Clone for V2EncryptedMigrationsGracePeriodStart
Sourcefn clone(&self) -> V2EncryptedMigrationsGracePeriodStart
fn clone(&self) -> V2EncryptedMigrationsGracePeriodStart
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<UT> ConvertError<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> ConvertError<UT> for V2EncryptedMigrationsGracePeriodStart
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<'de> Deserialize<'de> for V2EncryptedMigrationsGracePeriodStart
impl<'de> Deserialize<'de> for V2EncryptedMigrationsGracePeriodStart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for V2EncryptedMigrationsGracePeriodStart
Sourceimpl<UT> FfiConverter<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> FfiConverter<UT> for V2EncryptedMigrationsGracePeriodStart
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = <DateTime<Utc> as Lower<UniFfiTag>>::FfiType
type FfiType = <DateTime<Utc> as Lower<UniFfiTag>>::FfiType
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(obj: V2EncryptedMigrationsGracePeriodStart) -> Self::FfiType
fn lower(obj: V2EncryptedMigrationsGracePeriodStart) -> Self::FfiType
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(v: Self::FfiType) -> Result<V2EncryptedMigrationsGracePeriodStart>
fn try_lift(v: Self::FfiType) -> Result<V2EncryptedMigrationsGracePeriodStart>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<V2EncryptedMigrationsGracePeriodStart> for JsValue
impl From<V2EncryptedMigrationsGracePeriodStart> for JsValue
Sourcefn from(value: V2EncryptedMigrationsGracePeriodStart) -> Self
fn from(value: V2EncryptedMigrationsGracePeriodStart) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
impl FromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
Sourceimpl<UT> Lift<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> Lift<UT> for V2EncryptedMigrationsGracePeriodStart
Sourceimpl<UT> LiftRef<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> LiftRef<UT> for V2EncryptedMigrationsGracePeriodStart
Sourceimpl<UT> LiftReturn<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> LiftReturn<UT> for V2EncryptedMigrationsGracePeriodStart
Sourcetype ReturnType = <V2EncryptedMigrationsGracePeriodStart as Lift<UT>>::FfiType
type ReturnType = <V2EncryptedMigrationsGracePeriodStart as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> Lower<UT> for V2EncryptedMigrationsGracePeriodStart
Sourceimpl<UT> LowerError<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> LowerError<UT> for V2EncryptedMigrationsGracePeriodStart
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> LowerReturn<UT> for V2EncryptedMigrationsGracePeriodStart
Sourcetype ReturnType = <V2EncryptedMigrationsGracePeriodStart as Lower<UT>>::FfiType
type ReturnType = <V2EncryptedMigrationsGracePeriodStart as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
Sourceimpl RefFromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<V2EncryptedMigrationsGracePeriodStart>
type Anchor = SelfOwner<V2EncryptedMigrationsGracePeriodStart>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.impl StructuralPartialEq for V2EncryptedMigrationsGracePeriodStart
Sourceimpl TryFrom<JsValue> for V2EncryptedMigrationsGracePeriodStart
Available on crate feature wasm only.
impl TryFrom<JsValue> for V2EncryptedMigrationsGracePeriodStart
Available on crate feature
wasm only.Sourceimpl Tsify for V2EncryptedMigrationsGracePeriodStart
impl Tsify for V2EncryptedMigrationsGracePeriodStart
const DECL: &'static str = "/**\n * Records when the user first became eligible for v2 encrypted migrations.\n */\nexport type V2EncryptedMigrationsGracePeriodStart = DateTime<Utc>;"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for V2EncryptedMigrationsGracePeriodStart
impl<UT> TypeId<UT> for V2EncryptedMigrationsGracePeriodStart
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for V2EncryptedMigrationsGracePeriodStartwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for V2EncryptedMigrationsGracePeriodStart
impl VectorIntoWasmAbi for V2EncryptedMigrationsGracePeriodStart
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi